pub enum Layout {
SeparateChannels,
CombinedPerChannelType,
Combined,
}Expand description
Chart layout
Whether to plot channels on separate charts or combined charts.
Variants
SeparateChannels
Each channel plots on its own chart
CombinedPerChannelType
All input channels plot on one chart, all output channels plot on another chart
Same as Combined when config.with_inputs is false
Combined
All channels plot on one chart