SnapshotConfigBuilder

Struct SnapshotConfigBuilder 

pub struct SnapshotConfigBuilder { /* private fields */ }
Builder for SnapshotConfig.

Implementations

Source

impl SnapshotConfigBuilder

pub fn sample_rate(&mut self, value: f64) -> &mut Self

Sample rate of the audio unit.

Default is 44100.0 fundsp::DEFAULT_SR

pub fn num_samples(&mut self, value: usize) -> &mut Self

Number of samples to generate.

Default is 1024

pub fn processing_mode(&mut self, value: Processing) -> &mut Self

Processing mode for snapshotting an audio unit.

Default - Tick

pub fn warm_up(&mut self, value: WarmUp) -> &mut Self

Warm-up mode for snapshotting an audio unit.

Default - WarmUp::None

pub fn allow_abnormal_samples(&mut self, value: bool) -> &mut Self

How to handle abnormal samples: NaN,±Infinity

When set to true abnormal samples are allowed during processing, but skipped in actual output. Plotted with labeled dots.

When set to false and encoutered abnormal samples, the snapshotting process will panic.

pub fn output_mode<VALUE: Into<SnapshotOutputMode>>( &mut self, value: VALUE, ) -> &mut Self

Snaphsot output mode

Use configurable chart for visual snapshots

Use Wav16 or Wav32 for audial snapshots

pub fn try_output_mode<VALUE: TryInto<SnapshotOutputMode>>( &mut self, value: VALUE, ) -> Result<&mut Self, VALUE::Error>

Snaphsot output mode

Use configurable chart for visual snapshots

Use Wav16 or Wav32 for audial snapshots

pub fn build(&self) -> Result<SnapshotConfig, SnapshotConfigBuilderError>

Builds a new SnapshotConfig.

Errors

If a required field has not been initialized.

Source

impl SnapshotConfigBuilder

Legacy (v1.x) compatibility helpers

pub fn chart_layout(&mut self, value: Layout) -> &mut Self

Set chart layout.

pub fn with_inputs(&mut self, value: bool) -> &mut Self

Include inputs in chart.

pub fn svg_width(&mut self, value: usize) -> &mut Self

Set fixed SVG width.

pub fn svg_height_per_channel(&mut self, value: usize) -> &mut Self

Set SVG height per channel.

pub fn show_labels(&mut self, value: bool) -> &mut Self

Toggle label visibility.

pub fn format_x_axis_labels_as_time(&mut self, value: bool) -> &mut Self

Format X axis labels as time.

pub fn max_labels_x_axis(&mut self, value: Option<usize>) -> &mut Self

Set maximum number of X axis labels.

pub fn chart_title<S: Into<String>>(&mut self, value: S) -> &mut Self

Set chart title.

pub fn output_title<S: Into<String>>(&mut self, value: S) -> &mut Self

Add an output channel title.

pub fn input_title<S: Into<String>>(&mut self, value: S) -> &mut Self

Add an input channel title.

pub fn output_titles<S: Into<Vec<String>>>(&mut self, value: S) -> &mut Self

Add output channels’ titles.

pub fn input_titles<S: Into<Vec<String>>>(&mut self, value: S) -> &mut Self

Add input channels’ titles.

pub fn show_grid(&mut self, value: bool) -> &mut Self

Show grid lines.

pub fn line_width(&mut self, value: f32) -> &mut Self

Set waveform line width.

pub fn background_color<S: Into<String>>(&mut self, value: S) -> &mut Self

Set background color.

pub fn output_colors(&mut self, colors: Vec<String>) -> &mut Self

Replace all output channel colors.

pub fn output_color<S: Into<String>>(&mut self, value: S) -> &mut Self

Append one output channel color.

pub fn input_colors(&mut self, colors: Vec<String>) -> &mut Self

Replace all input channel colors.

pub fn input_color<S: Into<String>>(&mut self, value: S) -> &mut Self

Append one input channel color.