Module snapshot

Module snapshot 

Structs

AudioUnitSnapshotData
Raw sample buffers and metadata captured from one run of an audio unit.

Enums

SnapshotAbnormalSample
Describes a non-finite sample value captured during audio unit processing.

Functions

snapshot_audio_unit
Create a snapshot of audio unit outputs (default: SVG; configure output_mode for WAV)
snapshot_audio_unit_data
Capture raw sample data from an audio unit using default settings.
snapshot_audio_unit_data_with_input
Capture raw sample data from an audio unit driven by the given InputSource.
snapshot_audio_unit_data_with_input_and_options
Capture raw sample data from an audio unit with a given InputSource and SnapshotConfig.
snapshot_audio_unit_data_with_options
Capture raw sample data from an audio unit with custom SnapshotConfig settings.
snapshot_audio_unit_with_input
Create a snapshot of audio unit inputs and outputs (SVG by default; WAV if selected)
snapshot_audio_unit_with_input_and_options
Create a snapshot (inputs & outputs) with options (choose SVG chart or WAV via output_mode)
snapshot_audio_unit_with_options
Create a snapshot of audio unit outputs with options (SVG or WAV via output_mode)