SnapshotConfig

Struct SnapshotConfig 

pub struct SnapshotConfig {
    pub sample_rate: f64,
    pub num_samples: usize,
    pub processing_mode: Processing,
    pub warm_up: WarmUp,
    pub allow_abnormal_samples: bool,
    pub output_mode: SnapshotOutputMode,
}
Configuration for snapshotting an audio unit.

Fields

sample_rate: f64

Sample rate of the audio unit.

Default is 44100.0 fundsp::DEFAULT_SR

num_samples: usize

Number of samples to generate.

Default is 1024

processing_mode: Processing

Processing mode for snapshotting an audio unit.

Default - Tick

warm_up: WarmUp

Warm-up mode for snapshotting an audio unit.

Default - WarmUp::None

allow_abnormal_samples: bool

How to handle abnormal samples: NaN,±Infinity

When set to true abnormal samples are allowed during processing, but skipped in actual output. Plotted with labeled dots.

When set to false and encoutered abnormal samples, the snapshotting process will panic.

output_mode: SnapshotOutputMode

Snaphsot output mode

Use configurable chart for visual snapshots

Use Wav16 or Wav32 for audial snapshots

Implementations

Source

impl SnapshotConfig

pub fn file_name(&self, name: Option<&str>) -> String

Intnded for internal use only

Used by macros to determine snapshot filename

pub fn maybe_title(&mut self, name: &str)

Intnded for internal use only

Used by macros to set chart title if not already set