SnapshotConfig

Struct SnapshotConfig 

pub struct SnapshotConfig {
Show 20 fields pub sample_rate: f64, pub num_samples: usize, pub processing_mode: Processing, pub warm_up: WarmUp, pub allow_abnormal_samples: bool, pub chart_layout: Layout, pub with_inputs: bool, pub svg_width: Option<usize>, pub svg_height_per_channel: usize, pub show_labels: bool, pub format_x_axis_labels_as_time: bool, pub max_labels_x_axis: Option<usize>, pub chart_title: Option<String>, pub output_titles: Vec<String>, pub input_titles: Vec<String>, pub show_grid: bool, pub line_width: f32, pub background_color: String, pub output_colors: Option<Vec<String>>, pub input_colors: Option<Vec<String>>,
}
Configuration for snapshotting an audio unit.

Fields

sample_rate: f64

Sample rate of the audio unit.

Default is 44100.0 fundsp::DEFAULT_SR

num_samples: usize

Number of samples to generate.

Default is 1024

processing_mode: Processing

Processing mode for snapshotting an audio unit.

Default - Tick

warm_up: WarmUp

Warm-up mode for snapshotting an audio unit.

Default - WarmUp::None

allow_abnormal_samples: bool

How to handle abnormal samples: NaN,±Infinity

When set to true abnormal samples are allowed during processing, but skipped in actual output. Plotted with labeled dots.

When set to false and encoutered abnormal samples, the snapshotting process will panic.

chart_layout: Layout

Chart layout

Whether to plot channels on separate charts or combined charts.

Default - Layout::Separate

with_inputs: bool

Whether to include inputs in snapshot

Default - false

svg_width: Option<usize>

Optional width of the SVG viewBox

None means proportional to num_samples

svg_height_per_channel: usize

Height of one channel in the SVG viewBox

Default - 500

show_labels: bool

Show ax- labels

Default - true

format_x_axis_labels_as_time: bool

X axis labels format

Whether to format X axis labels as time

Default - false

max_labels_x_axis: Option<usize>

Maximum number of labels along X axis

Default - Some(5)

chart_title: Option<String>

Optional chart title

Default - None

output_titles: Vec<String>

Optional titles for output channels

Default - empty Vec

input_titles: Vec<String>

Optional titles for input channels

Default - empty Vec

show_grid: bool

Show grid lines on the chart

Default - false

line_width: f32

Waveform line thickness

Default - 2.0

background_color: String

Chart background color (hex string)

Default - “#000000” (black)

output_colors: Option<Vec<String>>

Custom colors for output channels (hex strings)

Default - None (uses default palette)

input_colors: Option<Vec<String>>

Custom colors for input channels (hex strings)

Default - None (uses default palette)