InputSource

Enum InputSource 

pub enum InputSource {
    None,
    VecByChannel(Vec<Vec<f32>>),
    VecByTick(Vec<Vec<f32>>),
    Flat(Vec<f32>),
    Generator(Box<dyn Fn(usize, usize) -> f32>),
}
Input provided to the audio unit

Variants



None

No input



VecByChannel(Vec<Vec<f32>>)

Input provided by a channel vec

  • First vec contains all channels
  • Second vec contains samples per channel


VecByTick(Vec<Vec<f32>>)

Input provided by a tick vec

  • First vec contains all ticks
  • Second vec contains samples for all channels per tick


Flat(Vec<f32>)

Input repeated on every tick

  • Vector contains samples for all channels for one tick


Generator(Box<dyn Fn(usize, usize) -> f32>)

Input provided by a generator function

  • First argument is the sample index
  • Second argument is the channel index

Implementations

Source

impl InputSource

pub fn impulse() -> Self

pub fn sine(freq: f32, sample_rate: f32) -> Self